@@ -11,7 +11,7 @@ class Foo(TestCase):
         pass
 
 
-class Bar(object):
+class Bar:
     def stuff(self):
         pass
 
@@ -19,7 +19,7 @@ class Bar(object):
         pass
 
 
-class Baz(object):
+class Baz:
     def test_bar(self):
         pass
 
@@ -27,13 +27,5 @@ class Baz(object):
         pass
 
 
-class OldStyle:
-    def thing(self):
-        pass
-
-    def test_old(self):
-        pass
-
-
 def test_123():
     pass
